/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.webapp.WebAppContext;

/**
 * In-Memory Jetty-Webserver.
 */
public class JettyServer {
    private static final Logger LOG = LoggerFactory.getLogger(JettyServer.class);

    private static final int DEFAULT_JETTY_SERVER_PORT = 42001;

    private Server server;
    private String warDestination;

    /**
     * Erzeugt den Webserver ohne ihn zu starten.
     * 
     * @param warDestination
     *            relativer Pfad zur WAR-Datei, die verwendet werden soll. Siehe
     *            auch {@link WebAppContext#setWar(String)}.
     */
    public JettyServer(String warDestination) {
        super();

        this.warDestination = warDestination;
    }

    /**
     * Startet den Webserver.
     */
    public void start() {

        if (server == null) {

            server = new Server(DEFAULT_JETTY_SERVER_PORT);

            WebAppContext webapp = new WebAppContext();
            webapp.setContextPath("/");
            webapp.setWar(warDestination);

            server.setHandler(webapp);

            // Webserver in neuem Thread starten.
            new Thread(new ServerThread(server)).start();
        }
    }

    /**
     * Stoppt den Webserver.
     */
    public void stop() {

        try {
            if (server != null) {
                server.stop();
                server = null;
            }
        } catch (Exception e) {
            LOG.error("Caught exception while shutting down jetty server!", e);
            throw new RuntimeException(e);
        }
    }

    /**
     * Thread zum Starten des Webservers.
     */
    private class ServerThread implements Runnable {
        private Server server;

        /**
         * Erzeugt ein neues Runnable.
         * 
         * @param server
         *            Webserver, der in dem Thread ausgeführt werden soll.
         */
        public ServerThread(Server server) {
            this.server = server;
        }

        /**
         * {@inheritDoc}.
         */
        public void run() {
            try {

                if (LOG.isInfoEnabled()) {
                    LOG.info("Starting Jetty server on port " + DEFAULT_JETTY_SERVER_PORT + ".");
                }

                // Startet den Server...
                server.start();
                // ...und blockiert den Thread.
                server.join();

                if (LOG.isInfoEnabled()) {
                    LOG.info("Jetty server terminated.");
                }

            } catch (InterruptedException e) {
                LOG.error("Caught exception while starting jetty server!", e);
                throw new RuntimeException(e);
            } catch (Exception e) {
                LOG.error("Caught exception while starting jetty server!", e);
                throw new RuntimeException(e);
            }
        }
    }
}
