/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example.model;

import de.conceptpeople.checkerberry.web.environment.ContextProvider;

/**
 * Model für die Homepage der Test-Web-Anwendung.
 */
public class UserlistPage extends AbstractBasePage {

    /**
     * Erzeugt ein neues Model für die Anzeige der Benutzerliste.
     * 
     * @param contextProvider
     *            Provider für die Kontextinformationen.
     */
    public UserlistPage(ContextProvider contextProvider) {
        super(contextProvider, "userList");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createUserlistTable() {
        return createComponentProxy("userTableId");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createFirstnameLabel(int rowNumber) {
        return createTableColumn(rowNumber, 1, "/span");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createSurnameLabel(int rowNumber) {
        return createTableColumn(rowNumber, 2, "/span");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createGenderLabel(int rowNumber) {
        return createTableColumn(rowNumber, 3, "/span");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createNewsletterLabel(int rowNumber) {
        return createTableColumn(rowNumber, 4, "/span");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createEditButton(int rowNumber) {
        return createTableColumn(rowNumber, 5, "/a");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente. Hier sieht
     * man wieder ein gutes Beispiel zu den Vorteilen des Modellansatzes. Der
     * Locator der einzelnen Zellen einer Tabelle können konfiguriert werden,
     * sodass Methoden mit einer einfachen API z.B. zur Angabe der Zeilennummer
     * verwendet werden können.
     * 
     * @param rowNumber
     *            Nummer der Zeile beginnend bei 1, wobei auch der Header als
     *            Zeile berücksichtigt wird.
     * @param columnNumber
     *            Nummer der Spalte beginnend bei 1.
     * @param suffix
     *            Erweiterung für den Lokator.
     * @return erzeute Proxy-Komponente.
     */
    private BaseComponent createTableColumn(int rowNumber, int columnNumber, String suffix) {
        return createComponentProxy("//table[@id='userTableId']/tbody/tr[" + rowNumber + "]/td["
                + columnNumber + "]" + suffix);
    }
}
